<?xml version="1.0" ?><!DOCTYPE TS><TS language="ms" version="2.1">
<context>
    <name>BMHandler</name>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="16"/>
        <source>Disk Format Error: Please reformat it or disable &quot;Auto scan USB storage devices&quot; in Security Center</source>
        <translation>Ralat Format Cakera: Sila format ia atau lumpuhkan &quot;Auto imbas peranti storan USB&quot; dalam Pusat Keselamatan</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="19"/>
        <source>Disk Format Error: Please reformat it</source>
        <translation>Ralat Format Cakera: Sila format ia</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="24"/>
        <source>Insufficient disk Space: Ensure that the disk has enough free space</source>
        <translation>Ruang cakera tidak mencukupi: Pastikan cakera mempunyai ruang bebas yang mencukupi</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="27"/>
        <source>Disk Mount Error: Insert the disk again or reboot to retry</source>
        <translation>Ralat Lekap Cakera: Sisipkan cakera sekali lagi atau but semula sistem untuk cuba sekali lagi</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="30"/>
        <source>Image Decompression Error: Verify md5 checksum of the image to ensure its integrity</source>
        <translation>Ralat Menyahmampat Imej: Sahkan hasil tambah semak md5 imej dan pastikan integritinya</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="33"/>
        <source>Internal Error</source>
        <translation>Ralat Dalaman</translation>
    </message>
</context>
<context>
    <name>BMWindow</name>
    <message>
        <location filename="../app/bmwindow.cpp" line="79"/>
        <source>Boot Maker is a simple tool to write system image files into USB flash drives and other media.</source>
        <translation>Pembuat But ialah sebuah alat ringkas yang dapat menulis fail imej sistem ke dalam pemacu pena USB dan lain-lain media.</translation>
    </message>
    <message>
        <location filename="../app/bmwindow.cpp" line="81"/>
        <source>Boot Maker</source>
        <translation>Pembuat But</translation>
    </message>
</context>
<context>
    <name>ISOSelectView</name>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="116"/>
        <source>Drag an ISO image file here</source>
        <translation>Seret satu fail imej ISO di sini</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="125"/>
        <source>OR</source>
        <translation>ATAU</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="82"/>
        <location filename="../app/view/isoselectview.cpp" line="140"/>
        <source>Select an ISO image file</source>
        <translation>Pilih satu fail imej ISO</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="170"/>
        <source>Next</source>
        <translation>Berikutnya</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="225"/>
        <source>Reselect an ISO image file</source>
        <translation>Pilih semula satu fail imej ISO</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="188"/>
        <source>Illegal ISO image file</source>
        <translation>Fail imej ISO tidak sah</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="328"/>
        <source>Detecting ISO file, please wait...</source>
        <translation>Mengesan fail ISO, tunggu sebentar...</translation>
    </message>
</context>
<context>
    <name>ProgressView</name>
    <message>
        <location filename="../app/view/progressview.cpp" line="51"/>
        <source>Burning</source>
        <translation>Merakam</translation>
    </message>
    <message>
        <location filename="../app/view/progressview.cpp" line="63"/>
        <source>Burning, please wait...</source>
        <translation>Merakam, tunggu sebentar...</translation>
    </message>
    <message>
        <location filename="../app/view/progressview.cpp" line="71"/>
        <source>Do not remove the disk or shut down the computer during the process</source>
        <translation>Jangan tanggalkan cakera atau matikan komputer ketika proses penyediaan masih berlangsung</translation>
    </message>
    <message>
        <location filename="../app/view/progressview.cpp" line="85"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Batal</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../libdbm/util/deviceinfo.h" line="40"/>
        <source>Removable Disk</source>
        <translation>Cakera Boleh Alih</translation>
    </message>
    <message>
        <location filename="../libdbm/util/utils.cpp" line="224"/>
        <location filename="../libdbm/util/utils.cpp" line="370"/>
        <source>Removable disk</source>
        <translation>Cakera boleh alih</translation>
    </message>
    <message>
        <location filename="../app/main.cpp" line="122"/>
        <source>Boot Maker</source>
        <translation>Pembuat But</translation>
    </message>
</context>
<context>
    <name>ResultView</name>
    <message>
        <location filename="../app/view/resultview.cpp" line="104"/>
        <source>Reboot now</source>
        <translation>But semula sekarang</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="56"/>
        <source>Successful</source>
        <translation>Berjaya</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="95"/>
        <source>Done</source>
        <comment>button</comment>
        <translation>Selesai</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="169"/>
        <source>The error log will be uploaded automatically with the feedback. We cannot improve without your feedback</source>
        <translation>Log ralat akan dimuat naik secara automatik bersama-sama maklum balas. Kami tidak dapat menambahbaik tanpa maklum balas dan sokongan anda</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="170"/>
        <source>Submit Feedback</source>
        <translation>Serah Maklum Balas</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="193"/>
        <source>After-Sale Services</source>
        <translation>Perkhidmatan Selepas-Jualan</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="206"/>
        <source>Close</source>
        <comment>button</comment>
        <translation>Tutup</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="214"/>
        <source>Sorry, process failed</source>
        <translation>Maaf, proses gagal</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="215"/>
        <source>Process failed</source>
        <translation>Proses gagal</translation>
    </message>
</context>
<context>
    <name>UnmountUsbView</name>
    <message>
        <location filename="../app/view/unmountusbview.cpp" line="13"/>
        <source>Verifying data and safely removing the media, please wait...</source>
        <translation>Mengesahkan data dan menanggalkan media secara selamat, tunggu sebentar...</translation>
    </message>
</context>
<context>
    <name>UsbSelectView</name>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="92"/>
        <source>Select a partition</source>
        <translation>Pilih sekatan</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="117"/>
        <source>Format the partition</source>
        <translation>Format sekatan</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="170"/>
        <source>Start</source>
        <translation>Mula</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="231"/>
        <source>Formatting will erase all data on the partition, but can increase the success rate, please confirm before proceeding</source>
        <translation>Pemformatan akan memadam semua data di dalam sekatan, dengan cara ini dapat meningkatkan kadar kejayaan, sila sahkan sebelum meneruskan operasi</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="377"/>
        <location filename="../app/view/usbselectview.cpp" line="388"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="380"/>
        <source>You have selected the ISO image in this USB flash drive. Formatting it will erase all your files. Please reselect the image file or cancel the formatting.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="384"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Batal</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="391"/>
        <source>Formatting the partition will overwrite all data, please have a backup before proceeding.</source>
        <translation>Pemformatan akan menulis-ganti semua data, sila sandar dahulu sebelum meneruskan operasi.</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="407"/>
        <source>Disk Format Error: Please format the partition with FAT32</source>
        <translation>Ralat Format Cakera: Sila format sekatan dengan FAT32</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="153"/>
        <source>No disk available</source>
        <translation>Tiada cakera tersedia</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="174"/>
        <source>Back</source>
        <comment>button</comment>
        <translation>Undur</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="358"/>
        <source>Format Partition</source>
        <translation>Format Sekatan</translation>
    </message>
</context>
</TS>